<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2006 m3 Media Services Limited                         |
| For contact details, see: http://www.m3.net/                              |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: Channel.plugin.php 5374 2006-08-25 12:37:44Z james.easterby@m3.net $
*/

/**
 * @package    MaxPlugins
 * @subpackage DeliveryLimitations
 * @author     Chris Nutting <chris@m3.net>
 */

require_once MAX_PATH . '/plugins/deliveryLimitations/DeliveryLimitations.php';
require_once MAX_PATH . '/lib/max/Plugin/Translation.php';

/**
 *
 * "Source" delivery limitation plugin.
 *
 */
class Plugins_DeliveryLimitations_Site_Channel extends Plugins_DeliveryLimitations  
{
    var $bannerid;
    var $agencyid;
    
    /**
     * Return name of plugin
     *
     * @return string
     */
    function getName()
    {
        return MAX_Plugin_Translation::translate('Channel', $this->module, $this->package);
    }
        
    /**
     * Return if this plugin is available in the current context
     *
     * @return boolean
     */
    function isAllowed($page = false)
    {
        if ($page != 'channel-acl.php') {
            return true;
        } else {
            return false;
        }
    }
    
    /**
     * Outputs the HTML to display the comparison operator for this limitation
     *
     * @return void
     */    
    function displayComparison()
    {
        echo "<select name='acl[{$this->executionorder}][comparison]' tabindex='".($tabindex++)."'>";
        echo "<option value='=='" . (($this->comparison == '==') ? ' selected="selected"' : '') . ">Is any of</option>";
        echo "<option value='=~'" . (($this->comparison == '=~') ? ' selected="selected"' : '') . ">Is all of</option>";
        echo "<option value='!~'" . (($this->comparison == '!~') ? ' selected="selected"' : '') . ">Is not any of</option>";
        echo "<option value='!='" . (($this->comparison == '!=') ? ' selected="selected"' : '') . ">Is not all of</option>";
        echo "</select>";
    }
    
    /**
     * Outputs the HTML to display the data for this limitation
     *
     * @return void
     */
    function displayData()
    {
        $conf = $GLOBALS['_MAX']['CONF'];
        $this->bannerid = (isset($GLOBALS['bannerid'])) ? $GLOBALS['bannerid'] : 0;
        $tabindex =& $GLOBALS['tabindex'];
        
        // Get list of all connnected publishers to chosen banner
        $res = phpAds_dbQuery("
            SELECT
                z.affiliateid
            FROM 
                {$conf['table']['prefix']}{$conf['table']['ad_zone_assoc']} AS aza,
                {$conf['table']['prefix']}{$conf['table']['zones']} AS z
            WHERE 
                aza.zone_id = z.zoneid
              AND aza.ad_id = {$this->bannerid}") or phpAds_sqlDie();

        $affiliates = array();
        while ($row = phpAds_dbFetchArray($res)) {
            $affiliates[] = $row['affiliateid'];
        }

        $res_agency = phpAds_dbQuery("
            SELECT
                a.agencyid
            FROM 
                {$conf['table']['prefix']}{$conf['table']['banners']} AS b,
                {$conf['table']['prefix']}{$conf['table']['campaigns']} AS m,
                {$conf['table']['prefix']}{$conf['table']['clients']} AS a
            WHERE 
                a.clientid = m.clientid
              AND m.campaignid = b.campaignid   
              AND b.bannerid = {$this->bannerid}") or phpAds_sqlDie();
        $this->agencyid = phpAds_dbResult($res_agency, 0, 0);

        $channels = Admin_DA::getChannels(array('channel_type' => 'admin'), true);
        
        if ($this->agencyid) {
            $channels = array_merge(
                $channels,
                Admin_DA::getChannels(array('agency_id' => $this->agencyid, 'channel_type' => 'agency'), true)
            );
        }
        
        $channels = array_merge(
            $channels,
            Admin_DA::getChannels(array('agency_id' => $this->agencyid, 'channel_type' => 'publisher'), true)
        );
        
        echo "<div class='box'>";
        foreach ($channels as $row) {
            if (!empty($row['publisher_id']) && !in_array($row['publisher_id'], $affiliates)) {
                continue;
            }
            echo "<div class='boxrow'>";
            echo "<input tabindex='".($tabindex++)."' ";
            echo "type='checkbox' id='c_{$this->executionorder}_{$row['channel_id']}' name='acl[{$this->executionorder}][data][]' value='{$row['channel_id']}'".(in_array($row['channel_id'], $this->data) ? ' checked="checked"' : '').">{$row['name']}</div>";
        }
        echo "</div>";
    }
    
    /**
     * If $this->data should be an array, this method loads the saved string into an array
     *
     * @return string
     */
    function loadData()
    {
        if (!is_array($this->data)) {
            $this->data = strlen($this->data) ? explode(',', $this->data) : array();
        }
        return true;
    }
    
    /**
     * Returns the data for this limitation
     *
     * @return string
     */
    function saveData()
    {
        return implode(',', $this->data);
    }
    
    /**
     * Returns the compiledlimitation string for this limitation
     *
     * @return string
     */
    function compile()
    {
        switch ($this->comparison) {
            case '==':
                $join = ' OR ';
                break;
            case '=~':
                $join = ' AND ';
                break;
            case '!~':
                $join = ' OR ';
                break;
            case '!=':
                $join = ' AND ';
                break;
        }
        $compile = array();
        foreach ($this->data as $channel) {
            $compile[] = 'MAX_check' . ucfirst($this->package) . '_' . $this->name . "(\'{$channel}\', \'==\', \$source)";
        }
        $ret =  ($this->comparison == '!~' || $this->comparison == '!=') ? ' !(' : '';
        $ret .= '(' . implode($join, $compile) . ')';
        $ret .= ($this->comparison == '!~' || $this->comparison == '!=') ? ')' : '';
        return $ret;
    }
}

?>
